summaryrefslogtreecommitdiff
path: root/src/include
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2017-06-20 13:40:17 +0200
committerChristian Grothoff <christian@grothoff.org>2017-06-20 13:40:17 +0200
commit39db1ae5dbbd12c0f452cfa56119d9a95f9b1b22 (patch)
treed1d04891fc363c7df78b42d9224d979b30bf971a /src/include
parent247f82c088dd1575709a676ab87555514fa6445e (diff)
downloadexchange-39db1ae5dbbd12c0f452cfa56119d9a95f9b1b22.tar.gz
exchange-39db1ae5dbbd12c0f452cfa56119d9a95f9b1b22.tar.bz2
exchange-39db1ae5dbbd12c0f452cfa56119d9a95f9b1b22.zip
address #5010 for /refresh/link
Diffstat (limited to 'src/include')
-rw-r--r--src/include/taler_exchangedb_plugin.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/include/taler_exchangedb_plugin.h b/src/include/taler_exchangedb_plugin.h
index 23e80c077..0406c8d19 100644
--- a/src/include/taler_exchangedb_plugin.h
+++ b/src/include/taler_exchangedb_plugin.h
@@ -1652,12 +1652,14 @@ struct TALER_EXCHANGEDB_Plugin
* @param cls the @e cls of this struct with the plugin-specific state
* @param session database connection
* @param session_hash session to get linkage data for
* @return all known link data for the session
*/
- struct TALER_EXCHANGEDB_LinkDataList *
+ enum GNUNET_DB_QueryStatus
(*get_link_data_list) (void *cls,
struct TALER_EXCHANGEDB_Session *session,
- const struct GNUNET_HashCode *session_hash);
+ const struct GNUNET_HashCode *session_hash,
+ struct TALER_EXCHANGEDB_LinkDataList **ldlp);
/**
@@ -1682,11 +1684,9 @@ struct TALER_EXCHANGEDB_Plugin
* @param coin_pub public key of the coin
* @param tdc function to call for each session the coin was melted into
* @param tdc_cls closure for @a tdc
- * @return #GNUNET_OK on success,
- * #GNUNET_NO on failure (not found)
- * #GNUNET_SYSERR on internal failure (database issue)
+ * @return statement execution status
*/
- int
+ enum GNUNET_DB_QueryStatus
(*get_transfer) (void *cls,
struct TALER_EXCHANGEDB_Session *session,
const struct TALER_CoinSpendPublicKeyP *coin_pub,
@@ -1652,12 +1652,14 @@ struct TALER_EXCHANGEDB_Plugin
* @param session database connection
* @param session_hash session to get linkage data for
- * @return all known link data for the session
+ * @param[out] ldldp set to all known link data for the session
+ * @return status of the transaction
*/